@@ -1,6 +1,6 @@
-"""Simple transparent wrapper for a small portion of Pika. It has a nice interface."""
+'''Simple messaging with RabbitMQ and Python.'''
 
-__version__ = '0.0.5'
+__version__ = '0.0.6'
 
 import logging
 import pickle
@@ -15,6 +15,7 @@ log.addHandler(logging.NullHandler())
 Errors = (
     pika.exceptions.ConnectionClosed,
     pika.exceptions.ChannelClosed,
+    pika.exceptions.ChannelWrongStateError,
 )
 
 
@@ -64,6 +65,7 @@ class Queue:
 
         self._declare_queue()
         self.channel.basic_qos(prefetch_count=1)
+        self.channel.confirm_delivery()
 
         self.stream = self.channel.consume(self.queue)
 
@@ -83,6 +85,7 @@ class Queue:
             routing_key=self.queue,
             body=pickle.dumps(msg),
             properties=pika.BasicProperties(delivery_mode=2, priority=priority),
+            mandatory=True,
         )
         
     def put(self, msg, priority=5):
@@ -174,3 +177,21 @@ class Queue:
 
         for msg in self:
             self._worker(msg)
+
+    def clear(self):
+        try:
+            self.channel.queue_purge(queue=self.queue)
+        except Errors as e:
+            log.debug(e)
+            self.setup()
+            self.channel.queue_purge(queue=self.queue)
+
+    def delete(self):
+        try:
+            self.channel.queue_delete(queue=self.queue)
+        except Errors as e:
+            log.debug(e)
+            self.setup()
+            self.channel.queue_delete(queue=self.queue)
+
+        self.disconnect()
